@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2015 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -28,3 +28,8 @@ try:
 except NameError:
     # Python 3
     long = int
+
+from decimal import Decimal
+
+NUMERIC_TYPES = (int, float, long, Decimal)
+
