@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2015 openpyxl
 
 
 """
@@ -100,6 +100,7 @@ class Set(Descriptor):
     def __init__(self, name=None, **kw):
         if not 'values' in kw:
             raise TypeError("missing set of values")
+        kw['values'] = set(kw['values'])
         super(Set, self).__init__(name, **kw)
 
     def __set__(self, instance, value):
@@ -108,6 +109,20 @@ class Set(Descriptor):
         super(Set, self).__set__(instance, value)
 
 
+class NoneSet(Set):
+
+    """'none' will be treated as None"""
+
+    def __init__(self, name=None, **kw):
+        super(NoneSet, self).__init__(name, **kw)
+        self.values.add(None)
+
+    def __set__(self, instance, value):
+        if value == 'none':
+            value = None
+        super(NoneSet, self).__set__(instance, value)
+
+
 class Integer(Convertible):
 
     expected_type = int
@@ -119,7 +134,7 @@ class Float(Convertible):
 
 
 class Bool(Convertible):
-
+    """ Boolean type - represents truth values `True` or `False` """
     expected_type = bool
 
     def __set__(self, instance, value):
@@ -210,7 +225,10 @@ class Alias(Descriptor):
         setattr(instance, self.alias, value)
 
     def __get__(self, instance, cls):
-        return getattr(instance, self.alias)
+        if instance:
+            return getattr(instance, self.alias)
+        else:
+            return getattr(cls, self.alias)
 
 
 class MetaStrict(type):
