@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2015 openpyxl
 
 """Read an xlsx file into Python"""
 
@@ -34,11 +34,11 @@ from openpyxl.xml.constants import (
 
 from openpyxl.workbook import Workbook, DocumentProperties
 from openpyxl.workbook.names.external import detect_external_links
+from openpyxl.workbook.names.named_range import read_named_ranges
 from openpyxl.reader.strings import read_string_table
 from openpyxl.reader.style import read_style_table
 from openpyxl.reader.workbook import (
     read_content_types,
-    read_named_ranges,
     read_properties_core,
     read_excel_base_date,
     detect_worksheets,
