@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2015 openpyxl
 
 """Worksheet is the 2nd-level container in Excel."""
 
@@ -138,7 +138,8 @@ class Worksheet(object):
         else:
             self.title = title
         self.row_dimensions = {}
-        self.column_dimensions = DimensionHolder([])
+        self.column_dimensions = DimensionHolder(worksheet=self,
+                                                 direction=[])
         self.page_breaks = []
         self._cells = {}
         self._styles = {}
@@ -322,9 +323,9 @@ class Worksheet(object):
             new_cell = openpyxl.cell.Cell(self, column, row)
             self._cells[coordinate] = new_cell
             if column not in self.column_dimensions:
-                self.column_dimensions[column] = ColumnDimension(column, worksheet=self)
+                self.column_dimensions[column] = ColumnDimension(index=column, worksheet=self)
             if row not in self.row_dimensions:
-                self.row_dimensions[row] = RowDimension(row, worksheet=self)
+                self.row_dimensions[row] = RowDimension(index=row, worksheet=self)
         return self._cells[coordinate]
 
     def __getitem__(self, key):
@@ -459,7 +460,7 @@ class Worksheet(object):
         :param range_string: `named range` name
         :type range_string: string
 
-        :rtype: tuples of tuples of :class:`openpyxl.cell.Cell
+        :rtype: tuples of tuples of :class:openpyxl.cell.Cell
         """
         named_range = self._parent.get_named_range(range_string)
         if named_range is None:
@@ -680,8 +681,16 @@ class Worksheet(object):
             for col_idx, content in enumerate(iterable, 1):
                 col = get_column_letter(col_idx)
                 if col not in self.column_dimensions:
-                    self.column_dimensions[col] = ColumnDimension(col)
-                cell = Cell(self, col, row_idx, content)
+                    self.column_dimensions[col] = ColumnDimension(worksheet=self, index=col)
+                if isinstance(content, Cell):
+                    # compatible with write-only mode
+                    cell = content
+                    cell.parent = self
+                    cell.column = col
+                    cell.row = row_idx
+                    cell.coordinate = "%s%s" % (col, row_idx)
+                else:
+                    cell = Cell(self, col, row_idx, content)
                 self._cells['%s%d' % (col, row_idx)] = cell
 
         elif isinstance(iterable, dict):
@@ -692,7 +701,7 @@ class Worksheet(object):
 
         else:
             self._invalid_row(iterable)
-        self.row_dimensions[row_idx] = RowDimension(row_idx)
+        self.row_dimensions[row_idx] = RowDimension(worksheet=self, index=row_idx)
 
     def _invalid_row(self, iterable):
         raise TypeError('Value must be a list, tuple, range or generator, or a dict. Supplied value is {0}'.format(
